Release notes
=============

.. roughly following https://sphinx-gallery.github.io/dev/maintainers.html,
.. 1.0.0 notes were generated by:
.. 1. tagging PRs as enhancement/bug/removed
.. 2. $ github_changelog_generator -u numpy -p numpydoc --since-tag=v0.9.2
.. 3. $ pandoc CHANGELOG.md --wrap=none -o release_notes.rst
.. 4. adding a manual addition (CSS note), tweaking heading levels, adding TOC

.. contents:: Page contents
   :local:
   :depth: 2

.. note::

   For release notes (sparsely) kept prior to 1.0.0, look at the `releases page
   on GitHub <https://github.com/numpy/numpydoc/releases>`__.

1.1.0
-----

Implemented enhancements
~~~~~~~~~~~~~~~~~~~~~~~~

-  MAINT: Suggestions from reviewing test suite `#271 <https://github.com/numpy/numpydoc/pull/271>`__ (`rossbar <https://github.com/rossbar>`__)
-  DEV: Add testing requirements `#267 <https://github.com/numpy/numpydoc/pull/267>`__ (`rossbar <https://github.com/rossbar>`__)
-  BUG: Defer to autodoc for signatures `#221 <https://github.com/numpy/numpydoc/pull/221>`__ (`thequackdaddy <https://github.com/thequackdaddy>`__)

Fixed bugs
~~~~~~~~~~

-  function signatures for \*args, \**kwargs objects off `#218 <https://github.com/numpy/numpydoc/issues/218>`__
-  BUG: Connect to earlier event `#269 <https://github.com/numpy/numpydoc/pull/269>`__ (`larsoner <https://github.com/larsoner>`__)

Closed issues
~~~~~~~~~~~~~

-  “Handler <function mangle_docstrings at 0x7f64b5ba57b8> for event ‘autodoc-process-docstring’ threw an exception” `#268 <https://github.com/numpy/numpydoc/issues/268>`__
-  Timing of next release `#249 <https://github.com/numpy/numpydoc/issues/249>`__
-  self included in list of params for method `#220 <https://github.com/numpy/numpydoc/issues/220>`__

Additional notes
~~~~~~~~~~~~~~~~

-  Due to merging of `#221 <https://github.com/numpy/numpydoc/pull/221>`__, self and cls no longer will appear in method signatures.


1.0.0
-----

Implemented enhancements
~~~~~~~~~~~~~~~~~~~~~~~~

-  ENH: Add args and kwargs to example `#258 <https://github.com/numpy/numpydoc/pull/258>`__ (`larsoner <https://github.com/larsoner>`__)
-  MAINT,STY: Upgrade to bionic, and change style similar to NumPy `#253 <https://github.com/numpy/numpydoc/pull/253>`__ (`mwtoews <https://github.com/mwtoews>`__)
-  Delay import of Sphinx `#248 <https://github.com/numpy/numpydoc/pull/248>`__ (`cgohlke <https://github.com/cgohlke>`__)
-  Adding –validate option \__main_\_ and run new validation `#240 <https://github.com/numpy/numpydoc/pull/240>`__ (`datapythonista <https://github.com/datapythonista>`__)
-  Add docstring validation script (from pandas) `#238 <https://github.com/numpy/numpydoc/pull/238>`__ (`datapythonista <https://github.com/datapythonista>`__)
-  ENH: Test full output and coverage `#230 <https://github.com/numpy/numpydoc/pull/230>`__ (`larsoner <https://github.com/larsoner>`__)
-  DOC: Add description for blank lines after the docstring. `#229 <https://github.com/numpy/numpydoc/pull/229>`__ (`bingyao <https://github.com/bingyao>`__)

Fixed bugs
~~~~~~~~~~

-  References outside function `#214 <https://github.com/numpy/numpydoc/issues/214>`__
-  FIX: Get doc of actual class in test `#262 <https://github.com/numpy/numpydoc/pull/262>`__ (`larsoner <https://github.com/larsoner>`__)
-  TST: Add inherited method `#260 <https://github.com/numpy/numpydoc/pull/260>`__ (`larsoner <https://github.com/larsoner>`__)
-  Fixes references outside function (#214) `#259 <https://github.com/numpy/numpydoc/pull/259>`__ (`Hoxbro <https://github.com/Hoxbro>`__)
-  Disable escaping “\*” on signature `#256 <https://github.com/numpy/numpydoc/pull/256>`__ (`tk0miya <https://github.com/tk0miya>`__)
-  MAINT: clean-up unused objects `#254 <https://github.com/numpy/numpydoc/pull/254>`__ (`mwtoews <https://github.com/mwtoews>`__)
-  STY: Reword first lines of example.py docstrings `#246 <https://github.com/numpy/numpydoc/pull/246>`__ (`justinludwig <https://github.com/justinludwig>`__)
-  DOC: Fixed three formatting issues in docs `#245 <https://github.com/numpy/numpydoc/pull/245>`__ (`rossbar <https://github.com/rossbar>`__)
-  STY Minor style improvements to doc/example.py to pass validation `#243 <https://github.com/numpy/numpydoc/pull/243>`__ (`rth <https://github.com/rth>`__)
-  BUG: Allow no . at end if indented `#239 <https://github.com/numpy/numpydoc/pull/239>`__ (`larsoner <https://github.com/larsoner>`__)
-  DOC: Update links and code checkers info in format.rst `#228 <https://github.com/numpy/numpydoc/pull/228>`__ (`bingyao <https://github.com/bingyao>`__)
-  DOC: Update links and info in conf.py. `#227 <https://github.com/numpy/numpydoc/pull/227>`__ (`bingyao <https://github.com/bingyao>`__)
-  BUG: Fix full rebuilds `#226 <https://github.com/numpy/numpydoc/pull/226>`__ (`larsoner <https://github.com/larsoner>`__)
-  MAINT: doctest and pytest `#225 <https://github.com/numpy/numpydoc/pull/225>`__ (`larsoner <https://github.com/larsoner>`__)
-  Py3fy some doctests. `#224 <https://github.com/numpy/numpydoc/pull/224>`__ (`anntzer <https://github.com/anntzer>`__)
-  MAINT: fix trivial source comment typos `#222 <https://github.com/numpy/numpydoc/pull/222>`__ (`luzpaz <https://github.com/luzpaz>`__)
-  Add missing headings to code examples `#252 <https://github.com/numpy/numpydoc/pull/252>`__ (`Cadair <https://github.com/Cadair>`__)

Removed
~~~~~~~

-  MNT Drop Python 2.7 and 3.4 support `#236 <https://github.com/numpy/numpydoc/pull/236>`__ (`rth <https://github.com/rth>`__)

Closed issues
~~~~~~~~~~~~~

-  Prefix added to reference keys in class docstrings `#263 <https://github.com/numpy/numpydoc/issues/263>`__
-  Test failure with python 3.9 `#261 <https://github.com/numpy/numpydoc/issues/261>`__
-  sphinx doc napoleon extension maintainer interest request `#251 <https://github.com/numpy/numpydoc/issues/251>`__
-  Missing reference to float_power function in the ufunc list `#250 <https://github.com/numpy/numpydoc/issues/250>`__

Additional notes
~~~~~~~~~~~~~~~~

-  CSS styling changed from NumpyDoc < 0.8 and Sphinx < 2.0 to more properly make use of definition lists. This can cause issues with rendering that can be fixed via CSS, especially when using ``sphinx-rtd-theme``. For more information, see:

   -  https://github.com/numpy/numpydoc/issues/215#issuecomment-568261611
   -  https://github.com/readthedocs/sphinx_rtd_theme/pull/838
